<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'travel_ultimate_pro_about_section', array(
	'title'             => esc_html__( 'About Us','travel-ultimate-pro' ),
	'description'       => esc_html__( 'About Section options.', 'travel-ultimate-pro' ),
	'panel'             => 'travel_ultimate_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_ultimate_pro_Switch_Control( $wp_customize, 'travel_ultimate_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_about_section',
	'on_off_label' 		=> travel_ultimate_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-ultimate-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-ultimate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'travel-ultimate-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
) );

$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_about_section',
	'choices'			=> travel_ultimate_pro_page_choices(),
	'active_callback'	=> 'travel_ultimate_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
) );

$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_about_section',
	'choices'			=> travel_ultimate_pro_post_choices(),
	'active_callback'	=> 'travel_ultimate_pro_is_about_section_content_post_enable',
) ) );

// image setting and control.
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_ultimate_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travel-ultimate-pro' ),
		'section'     		=> 'travel_ultimate_pro_about_section',
		'active_callback'	=> 'travel_ultimate_pro_is_about_section_content_custom_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_about_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[about_title]', array(
		'selector'            => '#about-us .section-header .section-title',
		'settings'            => 'travel_ultimate_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_about_title_partial',
    ) );
}

if ( $options['home_layout'] == 'default-design' ):
// about btn title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_about_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us .section-header .section-subtitle',
		'settings'            => 'travel_ultimate_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_about_sub_title_partial',
    ) );
}

endif;

// about description setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_about_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[about_description]', array(
		'selector'            => '#about-us .section-content p',
		'settings'            => 'travel_ultimate_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_about_description_partial',
    ) );
}

// about btn title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[about_button]', array(
	'label'           	=> esc_html__( 'Button Text', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_about_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[about_button]', array(
		'selector'            => '#business-about-us .wrapper .business-read-more a',
		'settings'            => 'travel_ultimate_pro_theme_options[about_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_about_button_partial',
    ) );
}

// about hr setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[about_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new travel_ultimate_pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[about_hr]',
	array(
		'section'         => 'travel_ultimate_pro_about_section',
		'active_callback' => 'travel_ultimate_pro_is_about_section_enable',
		'type'			  => 'hr'
) ) );

if ( $options['home_layout'] == 'default-design' ):

// About content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[tour_content_type]', array(
	'default'          	=> $options['tour_content_type'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[tour_content_type]', array(
	'label'             => esc_html__( 'Tour Content Type', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_about_section_enable',
	'choices'			=> array( 
		'cat' 		=> esc_html__( 'Category', 'travel-ultimate-pro' ),
		'destination' 		=> esc_html__( 'Destination', 'travel-ultimate-pro' ),
		'trip-types' 		=> esc_html__( 'Trip Type', 'travel-ultimate-pro' ),
	),
) );


// slider number control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[tour_count]', array(
	'default'          	=> $options['tour_count'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[tour_count]', array(
	'label'             => esc_html__( 'Number of tours', 'travel-ultimate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_about_section',
	'active_callback'   => 'travel_ultimate_pro_is_about_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['tour_count']; $i++ ) { 
	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[tour_cat_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[tour_cat_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select category %d', 'travel-ultimate-pro' ), $i ),
		'description'      	=> esc_html__( 'Note: Selected category\'s no of posts will be shown from selected category', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_about_section',
		'type'              => 'dropdown-categories',
		'active_callback'	=> 'travel_ultimate_pro_is_tour_cat_enable'
	) ) );

	// Add dropdown destinations setting and control.
	$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[tour_destinations_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[tour_destinations_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select destinations %d', 'travel-ultimate-pro' ), $i ),
		'description'      	=> esc_html__( 'Note: Selected destination\'s no of posts will be shown from selected category', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_about_section',
		'type'              => 'dropdown-taxonomies',
		'taxonomy'			=> 'travel_locations',
		'active_callback'	=> 'travel_ultimate_pro_is_tour_destinations_enable'
	) ) );

	// Add dropdown destinations setting and control.
	$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[tour_trip_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[tour_trip_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select trip type %d', 'travel-ultimate-pro' ), $i ),
		'description'      	=> esc_html__( 'Note: Selected trip type\'s no of posts will be shown from selected category', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_about_section',
		'type'              => 'dropdown-taxonomies',
		'taxonomy'			=> 'itinerary_types',
		'active_callback'	=> 'travel_ultimate_pro_is_tour_trip_enable'
	) ) );

	// tour image setting and control.
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[tour_image_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_ultimate_pro_theme_options[tour_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'travel-ultimate-pro' ), $i ),
			'section'     		=> 'travel_ultimate_pro_about_section',
			'active_callback'	=> 'travel_ultimate_pro_is_about_section_enable',
	) ) );

	// about hr setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[tour_type_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new travel_ultimate_pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[tour_type_' . $i . ']',
		array(
			'section'         => 'travel_ultimate_pro_about_section',
			'active_callback' => 'travel_ultimate_pro_is_about_section_enable',
			'type'			  => 'hr'
	) ) );
}

endif;